@@ -211,7 +211,6 @@ class CloneMixin(object):
             for name, value in attrs.items():
                 setattr(duplicate, name, value)
 
-        duplicate.full_clean()
         duplicate.save()
 
         duplicate = self.__duplicate_o2o_fields(duplicate)
@@ -509,7 +508,12 @@ class CloneMixin(object):
                 objs = through.objects.filter(**{field_name: self.pk})
                 for item in objs:
                     if hasattr(through, "make_clone"):
-                        item.make_clone(attrs={field_name: duplicate}, sub_clone=True)
+                        try:
+                            item.make_clone(attrs={field_name: duplicate})
+                        except IntegrityError:
+                            item.make_clone(
+                                attrs={field_name: duplicate}, sub_clone=True
+                            )
                     else:
                         item.pk = None
                         setattr(item, field_name, duplicate)
